# MailUpdater

A Python module for easily sending mail updates to yourself.

This program only works for Gmail at the moment.

For the program to work, **you must enable [less secure app access](https://myaccount.google.com/security).**

## Quickstart

See this [example](mailupdater/example.py).

## Installation

```bash
pip3 install mailupdater
```

## Testing

Do:

```python3

import mailupdater

mailupdater.test()

```

Then follow the instructions of the program.

If the program finishes successfully, then you should see two new emails in your inbox.

